[libvirt] [libvirt-designer][PATCH] virtxml: Rename to virt-designer

Michal Privoznik mprivozn at redhat.com
Thu Jan 30 12:23:06 UTC 2014


Our example utility is called virtxml. However with Cole's latest work,
where he introduced virt-xml binary for editing libvirt XML on CLI [1].
It would be better if our example is called virt-designer so we don't
confuse users.

1: https://www.redhat.com/archives/libvir-list/2014-January/msg01226.html

Signed-off-by: Michal Privoznik <mprivozn at redhat.com>
---
 .gitignore                              |  2 +-
 cfg.mk                                  |  2 +-
 configure.ac                            |  2 +-
 examples/Makefile.am                    | 10 +++++-----
 examples/{virtxml.c => virt-designer.c} | 32 ++++++++++++++++----------------
 libvirt-designer.spec.in                |  4 ++--
 6 files changed, 26 insertions(+), 26 deletions(-)
 rename examples/{virtxml.c => virt-designer.c} (96%)

diff --git a/.gitignore b/.gitignore
index 6b05db9..09e15a5 100644
--- a/.gitignore
+++ b/.gitignore
@@ -15,7 +15,7 @@ Makefile.in
 /config.log
 /config.status
 /configure
-/examples/virtxml
+/examples/virt-designer
 /libtool
 /libvirt-designer-1.0.pc
 /libvirt-designer.spec
diff --git a/cfg.mk b/cfg.mk
index 1e4b31d..f9ab008 100644
--- a/cfg.mk
+++ b/cfg.mk
@@ -104,7 +104,7 @@ sc_copyright_format:
 prev_version_file = /dev/null
 
 
-exclude_file_name_regexp--sc_bindtextdomain = ^libvirt-designer/(test|libvirt-designer-main\.c)|^examples/virtxml\.c$$
+exclude_file_name_regexp--sc_bindtextdomain = ^libvirt-designer/(test|libvirt-designer-main\.c)|^examples/virt-designer\.c$$
 
 exclude_file_name_regexp--sc_preprocessor_indentation = ^*/*.[ch]$$
 
diff --git a/configure.ac b/configure.ac
index bad199b..595fea4 100644
--- a/configure.ac
+++ b/configure.ac
@@ -96,7 +96,7 @@ LIBVIRT_DESIGNER_COVERAGE
 LIBVIRT_DESIGNER_INTROSPECTION
 
 AC_ARG_ENABLE([examples],
-              AS_HELP_STRING([--enable-examples], [enable virtxml example. Default is check, meaning it is enabled as long as libvirt-gobject is installed]),
+              AS_HELP_STRING([--enable-examples], [enable virt-designer example. Default is check, meaning it is enabled as long as libvirt-gobject is installed]),
               [],[enable_examples=check])
 
 if test "x$enable_examples" != "xno" ; then
diff --git a/examples/Makefile.am b/examples/Makefile.am
index ae2667e..1d8947f 100644
--- a/examples/Makefile.am
+++ b/examples/Makefile.am
@@ -2,10 +2,10 @@ INCLUDES = \
 		-I$(top_builddir)/libvirt-designer	\
 		-I$(top_srcdir)
 
-virtxml_LDADD = \
+virt_designer_LDADD = \
 		$(top_builddir)/libvirt-designer/libvirt-designer-1.0.la
 
-virtxml_CFLAGS = \
+virt_designer_CFLAGS = \
 		$(COVERAGE_CFLAGS) \
 		$(LIBOSINFO_CFLAGS) \
 		$(LIBVIRT_GCONFIG_CFLAGS) \
@@ -13,7 +13,7 @@ virtxml_CFLAGS = \
 		$(LIBVIRT_GOBJECT_CFLAGS) \
 		$(NULL)
 
-virtxml_LDFLAGS = \
+virt_designer_LDFLAGS = \
 		$(LIBOSINFO_LIBS) \
 		$(LIBVIRT_GCONFIG_LIBS) \
 		$(LIBVIRT_GOBJECT_LIBS)
@@ -24,9 +24,9 @@ POD2MAN = pod2man -c "Virtualization Support" -r "$(PACKAGE)-$(VERSION)"
 	$(AM_V_GEN)$(POD2MAN) $< $@
 
 if WITH_EXAMPLES
-bin_PROGRAMS = virtxml
+bin_PROGRAMS = virt-designer
 
-man1_MANS = virtxml.1
+man1_MANS = virt-designer.1
 
 CLEANFILES = $(man1_MANS)
 endif
diff --git a/libvirt-designer.spec.in b/libvirt-designer.spec.in
index 894bcb8..fb5c70a 100644
--- a/libvirt-designer.spec.in
+++ b/libvirt-designer.spec.in
@@ -78,8 +78,8 @@ rm -rf $RPM_BUILD_ROOT
 
 %files
 %defattr(-,root,root,-)
-%{_bindir}/virtxml
-%{_mandir}/man1/virtxml.1*
+%{_bindir}/virt-designer
+%{_mandir}/man1/virt-designer.1*
 
 %files libs
 %defattr(-,root,root,-)
diff --git a/examples/virtxml.c b/examples/virt-designer.c
similarity index 96%
rename from examples/virtxml.c
rename to examples/virt-designer.c
index 6fb51d5..7628449 100644
--- a/examples/virtxml.c
+++ b/examples/virt-designer.c
@@ -1,7 +1,7 @@
 /*
  * virtxml.c: produce an domain XML
  *
- * Copyright (C) 2012 Red Hat, Inc.
+ * Copyright (C) 2012, 2014 Red Hat, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -750,26 +750,26 @@ cleanup:
 
 =head1 NAME
 
-virtxml - Generate domain XML
+virt-designer - Generate domain XML
 
 =head1 SYNOPSIS
 
-B<virtxml> [I<OPTION>]...
+B<virt-designer> [I<OPTION>]...
 
 =head1 DESCRIPTION
 
-B<virtxml> is a command line tool for generating XML documents for
+B<virt-designer> is a command line tool for generating XML documents for
 libvirt domains. However, it cooperates with libosinfo database to guess
 the correct combination of attributes (e.g. disk driver, NIC model).
 
-B<virtxml> does not feed libvirt with generated XML though. For now,
+B<virt-designer> does not feed libvirt with generated XML though. For now,
 it's a proof of concept.
 
 =head1 OPTIONS
 
-The basic structure of arguments passed to B<virtxml> is:
+The basic structure of arguments passed to B<virt-designer> is:
 
-  virtxml [-c URI] [OPTION] [OPTION] ...
+  virt-designer [-c URI] [OPTION] [OPTION] ...
 
 However, arguments have no pre-defined order so users can type them
 in any order they like.
@@ -844,7 +844,7 @@ the I<recommended> is used.
 Usually, both B<--os> and B<--platform> are required as they are needed to
 make the right decision on driver, model, ...  when adding a new device.
 However, when adding a disk which is an installation medium (e.g. a CD-ROM or
-DVD), B<virtxml> tries to guess the OS. Something similar is done with
+DVD), B<virt-designer> tries to guess the OS. Something similar is done with
 platform. Usually, the platform is guessed from the connection URI.
 
 =head1 EXAMPLES
@@ -852,16 +852,16 @@ platform. Usually, the platform is guessed from the connection URI.
 Domain with Fedora 17 from locally stored ISO and one NIC with mac
 00:11:22:33:44:55 and link set down:
 
-  # virtxml -C Fedora-17-x86_64-Live-KDE.iso \
-            -i default,mac=00:11:22:33:44:55,link=down
+  # virt-designer -C Fedora-17-x86_64-Live-KDE.iso \
+                  -i default,mac=00:11:22:33:44:55,link=down
 
 To add multiple devices just use appropriate argument multiple times:
 
-  # virtxml -d /tmp/home.img,qcow2 \
-            -d /var/lib/libvirt/images/f17.img,qcow2 \
-            -i default,mac=00:11:22:33:44:55,link=down \
-            -i blue_network \
-            -r minimal
+  # virt-designer -d /tmp/home.img,qcow2 \
+                  -d /var/lib/libvirt/images/f17.img,qcow2 \
+                  -i default,mac=00:11:22:33:44:55,link=down \
+                  -i blue_network \
+                  -r minimal
 
 =head1 AUTHORS
 
@@ -1,7 +1,7 @@
 /*
- * virtxml.c: produce an domain XML
+ * virt-designer.c: produce an domain XML
  *
-- 
1.8.5.2




More information about the libvir-list mailing list